@@ -1,7 +1,7 @@
 package File::Unsaved;
 
-our $DATE = '2014-12-24'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -159,7 +159,7 @@ File::Unsaved - Check whether file has unsaved modification in an editor
 
 =head1 VERSION
 
-This document describes version 0.04 of File::Unsaved (from Perl distribution File-Unsaved), released on 2014-12-24.
+This document describes version 0.05 of File::Unsaved (from Perl distribution File-Unsaved), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
@@ -221,9 +221,8 @@ differently-named fork/derivative of said editor, although this should be rare.
 
 =back
 
-Return value:
+Return value:  (bool|hash)
 
- (any)
 
 Return false if no unsaved data is detected, or else a hash structure. Hash will
 contain these keys: C<editor> (kind of editor, possible values: C<emacs>,
@@ -254,7 +253,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
